package sample.ACSE_Request;

import com.objsys.csta2.*;
import com.objsys.asn1j.runtime.*;

public class Writer
{
	public static void main(String[] args)
	{
		String filename = new StringBuffer("message.dat").toString();
		boolean trace = true;
		
		// Process command line arguments
		
		if (args.length > 0)
		{
			for (int i = 0; i < args.length; i++)
			{
				if (args[i].equals("-v"))
					Diag.instance().setEnabled(true);
				else if (args[i].equals("-o"))
					filename = new StringBuffer(args[++i]).toString();
				else if (args[i].equals("-notrace"))
					trace = false;
				else
				{
					System.out.println("usage: Writer [ -v ] [ -o <filename>");
					System.out.println("   -v  verbose mode: print trace info");
					System.out.println("   -o <filename>  " + "write Encoded msg to <filename>");
					System.out.println("   -notrace  do not display trace info");
					return ;
				}
			}
		}
		
		// Create a data object and populate it with the data to be Encoded
		
      AARQ_apdu aarq_apdu = new AARQ_apdu();
     
      /*
      set CSTA 3 OID value, for CSTA 3 communication 
      { iso( 1) identified-organization( 3) icd-ecma( 12)
      standard( 0) csta2( 218) }
      */
      aarq_apdu.aSO_context_name = 
         new ASO_context_name(new int[]{1, 3, 12, 0, 218 });

      /*
      For simplicity, following data is ignored

      It is necessary for the requesting and responding systems to specify
      the CSTA services that they support. As with the protocol version information, 
      this is also achieved by carrying additional information in the 
      AARQ_apdu.user-information field of the request and response PDUs. The
      application association requestor shall:
      . list the services required from the serving application;
      . list the services it can supply.
      */

      /* All other optional fields are ignored for simplicity */

      /* Encode */
      ACSE_apdu acse_apdu = new ACSE_apdu();
      acse_apdu.set_aarq(aarq_apdu);

      // Create a message buffer object and Encode the record
      Asn1BerEncodeBuffer encodeBuffer = new Asn1BerEncodeBuffer();

      try
      {

         acse_apdu.encode(encodeBuffer, true);

			if (trace)
			{
				System.out.println("Encoding was successful");
				System.out.println("Hex dump of Encoded record:");
				encodeBuffer.hexDump();
				System.out.println("Binary dump:");
				encodeBuffer.binDump();
			}

			// Write the Encoded record to a file
			
			encodeBuffer.write(new java.io.FileOutputStream(filename));
			
			// Generate a dump file for comparisons
			
			java.io.PrintStream messagedmp = new java.io.PrintStream(new java.io.FileOutputStream("message.dmp"));

			encodeBuffer.hexDump(messagedmp);
      }
      catch (Exception e)
      {
         System.out.println("Encode of ACSE AARQ failed.");
         System.out.println(e.getMessage());
         e.printStackTrace();
         return;
      }
	}

}