package sample.ACSE_Response;

import java.io.IOException;

import com.objsys.asn1j.runtime.*;
import com.objsys.csta2.*;

public class Writer
{
	
	public static void  main (String[] args)
	{
		String filename = 
         new StringBuffer("message.dat").toString();
	 boolean trace = true;
		
		// Process command line arguments
		
		if (args.length > 0)
		{
			for (int i = 0; i < args.length; i++)
			{
				if (args[i].equals("-v"))
					Diag.instance().setEnabled(true);
				else if (args[i].equals("-o"))
					filename = new StringBuffer(args[++i]).toString();
				else if (args[i].equals("-notrace"))
					trace = false;
				else
				{
					System.out.println("usage: Writer [ -v ] [ -o <filename>");
					System.out.println("   -v  verbose mode: print trace info");
					System.out.println("   -o <filename>  " + "write Encoded msg to <filename>");
					System.out.println("   -notrace  do not display trace info");
					return ;
				}
			}
		}
		
      // Create a message buffer object and Encode the record
      try
      {
         encodeACSEConnectionResponse(trace, filename);
      }
      catch (Exception e)
      {
         System.out.println("Encode of ACSE message failed.");
         System.out.println(e.getMessage());
         e.printStackTrace();
         return;
      }
	}


   /* Encode ACSE Connection Response 

   The ACSE_apdu.aare(response) is transmitted to the CSTA Application,
   waitting for a response for an ACSE_apdu.aarq(request). 
   */
   static void encodeACSEConnectionResponse (boolean trace, String filename)
      throws Asn1Exception, IOException
   {
      AARE_apdu aare_apdu = new AARE_apdu();
     
      /*
      set CSTA 3 OID value, for CSTA 3 communication 
      { iso( 1) identified-organization( 3) icd-ecma( 12)
      standard( 0) csta2( 218) }
      */
      aare_apdu.aSO_context_name = 
         new ASO_context_name(new int[]{1, 3, 12, 0, 218 });
      
      aare_apdu.result = new Associate_result(Associate_result.accepted);
      aare_apdu.result_source_diagnostic = 
         new Associate_source_diagnostic();
      aare_apdu.result_source_diagnostic.set_acse_service_provider
         (new Associate_source_diagnostic_acse_service_provider(
            Associate_source_diagnostic_acse_service_provider.null_));

      /* All other optional fields are ignored for simplicity */

      ACSE_apdu acse_apdu = new ACSE_apdu();
      acse_apdu.set_aare(aare_apdu);
 
      /* Encode */
      Asn1BerEncodeBuffer encodeBuffer = new Asn1BerEncodeBuffer();
      acse_apdu.encode(encodeBuffer, true);
      printMessage(encodeBuffer, trace, filename);
   }

   /* Encode ACSE connection Release Response 

   The ACSE_apdu.rlre(response) is transmitted to the CSTA Application,
   waitting for a response for an ACSE_apdu.rlrq(request). 

   */
   static void encodeACSEReleaseResponse (boolean trace, String filename)
      throws Asn1Exception, IOException
   {
      RLRE_apdu rlre_apdu = new RLRE_apdu();

      rlre_apdu.reason = new Release_response_reason
         (Release_response_reason.normal);

      /* All other optional fields are ignored for simplicity. */

      ACSE_apdu acse_apdu = new ACSE_apdu();
      acse_apdu.set_rlre(rlre_apdu);

      /* Encode */
      Asn1BerEncodeBuffer encodeBuffer = new Asn1BerEncodeBuffer();
      acse_apdu.encode(encodeBuffer, true);
      printMessage(encodeBuffer, trace, filename);
   }

   /* Encode ACSE connection abort, this is not a Request */
   static void encodeACSEAbort (boolean trace, String filename)
      throws Asn1Exception, IOException
   {
      ABRT_apdu abrt_apdu = new ABRT_apdu();

      abrt_apdu.abort_source = 
         new ABRT_source(ABRT_source.acse_service_user);

      /* All other optional fields are ignored for simplicity. */

      ACSE_apdu acse_apdu = new ACSE_apdu();
      acse_apdu.set_abrt(abrt_apdu);

      /* Encode */
      Asn1BerEncodeBuffer encodeBuffer = new Asn1BerEncodeBuffer();
      acse_apdu.encode(encodeBuffer, true);
      printMessage(encodeBuffer, trace, filename);
   }

   /* Encode ACSE connection abort, this is not a Request */
   static void printMessage (Asn1BerEncodeBuffer encodeBuffer, 
      boolean trace, String filename)
      throws IOException
   {
      if (trace)
      {
         System.out.println("Encoding was successful");
         System.out.println("Hex dump of Encoded record:");
         encodeBuffer.hexDump();
         System.out.println("Binary dump:");
         encodeBuffer.binDump();
      }

      // Write the Encoded record to a file
      
      encodeBuffer.write(new java.io.FileOutputStream(filename));
      
      // Generate a dump file for comparisons
      
      java.io.PrintStream messagedmp = new java.io.PrintStream(new java.io.FileOutputStream("message.dmp"));
      
      encodeBuffer.hexDump(messagedmp);
   }

}
