package sample.MakeCallResponse;

import java.io.IOException;

import com.objsys.asn1j.runtime.*;
import com.objsys.csta2.*;

/* Test driver to read and decode an encoded ASN.1 message 
 * This file provides sample code for processing the PBX response
 *
 */


public class Reader {
   
   public static final void main( String[]args )
   {
      try {
      String filename = "message.dat";
      boolean trace = true;
      
      // Process command line arguments
      
      if (args.length > 0)
      {
         for (int i = 0; i < args.length; i++)
         {
            if (args[i].equals("-v"))
               Diag.instance().setEnabled(true);
            else if (args[i].equals("-i"))
               filename = args[++i];
            else if (args[i].equals("-notrace"))
               trace = false;
            else
            {
               System.out.println("usage: Reader [ -v ] [ -i <filename> ]");
               System.out.println("   -v  verbose mode: print trace info");
               System.out.println("   -i <filename>  " + "read Encoded msg from <filename>");
               System.out.println("   -notrace  do not display trace info");
               return ;
            }
         }
      }
      
      // Create an input file stream object
      java.io.FileInputStream ins = new java.io.FileInputStream(filename);
      
      // Create a Decode buffer object
      Asn1BerDecodeBuffer decodeBuffer = new Asn1BerDecodeBuffer(ins);
   
      /* Decode ROSE header */
      CSTA_ROSE_PDU pdu = new CSTA_ROSE_PDU();
   
      pdu.decode(decodeBuffer);
   
      if (trace) {
         System.out.println ("Decode of ROSE PDU was successful\n");
         pdu.print(System.out, "pdu", 0);
      }
   
      /* Process the ROSE operation */
      processPDU(pdu, trace);
   
      }
      catch (Exception e)
      {
         System.out.println(e.getMessage());
         e.printStackTrace();
         return ;
      }
   }

   private static void processPDU(CSTA_ROSE_PDU pdu, boolean trace)
      throws Asn1Exception, IOException
   {
      switch(pdu.getChoiceID()) {
      case CSTA_ROSE_PDU._INVOKE: {
            processInvoke(pdu, trace);
            } break;
      case CSTA_ROSE_PDU._RETURNRESULT: {
            processReturnResult(pdu, trace);
            } break;
      case CSTA_ROSE_PDU._RETURNERROR: {
            processReturnError(pdu, trace);
            } break;
      case CSTA_ROSE_PDU._REJECT: {         
            processReject(pdu, trace);
            } break;
         default: { } break;
      }
   }
   

private static void processInvoke(CSTA_ROSE_PDU pdu, boolean trace)
   throws Asn1Exception, IOException
{
   /*
   CSTA_ROSE_PDU_invoke.argument(opentype) needs to be decoded/encoded
   using CSTA_ROSE_PDU_invoke.opcode value as defined in Table 1.
   */
   CSTA_ROSE_PDU_invoke invoke = (CSTA_ROSE_PDU_invoke)pdu.getElement();
   if ( invoke.opcode.getChoiceID() != Code._LOCAL ) {
      System.out.println("ROSE Operation's Invoke.parameter type is not known\n");
      return;
   }

   Asn1BerDecodeBuffer decodeBuffer2 = new Asn1BerDecodeBuffer(
         invoke.argument.value );

   Asn1Integer local = (Asn1Integer) invoke.opcode.getElement();
   switch((int)local.value ) {
      case 1: {   /* alternateCall operation Request */
            AlternateCallArgument alternateCallArg = new AlternateCallArgument();
            alternateCallArg.decode(decodeBuffer2);
               /* process the "alternateCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of AlternateCallArgument was successful\n");
                  alternateCallArg.print(System.out, "AlternateCallArgument", 0);
               }
         } break;

      case 2: {   /* answerCall operation Request */
            AnswerCallArgument answerCallArg = new AnswerCallArgument();
            answerCallArg.decode(decodeBuffer2);
               /* process the "answerCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of AnswerCallArgument was successful\n");
                  answerCallArg.print(System.out, "AnswerCallArgument", 0);
               }
         } break;

      case 17: {   /* associateData operation Request */
            AssociateDataArgument associateDataArg = new AssociateDataArgument();
            associateDataArg.decode(decodeBuffer2);
               /* process the "associateData" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of AssociateDataArgument was successful\n");
                  associateDataArg.print(System.out, "AssociateDataArgument", 0);
               }
         } break;

      case 3: {   /* callCompletion operation Request */
            CallCompletionArgument callCompletionArg = new CallCompletionArgument();
            callCompletionArg.decode(decodeBuffer2);
               /* process the "callCompletion" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of CallCompletionArgument was successful\n");
                  callCompletionArg.print(System.out, "CallCompletionArgument", 0);
               }
         } break;

      case 4: {   /* clearCall operation Request */
            ClearCallArgument clearCallArg = new ClearCallArgument();
            clearCallArg.decode(decodeBuffer2);
               /* process the "clearCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ClearCallArgument was successful\n");
                  clearCallArg.print(System.out, "ClearCallArgument", 0);
               }
         } break;

      case 5: {   /* clearConnection operation Request */
            ClearConnectionArgument clearConnectionArg = new ClearConnectionArgument();
            clearConnectionArg.decode(decodeBuffer2);
               /* process the "clearConnection" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ClearConnectionArgument was successful\n");
                  clearConnectionArg.print(System.out, "ClearConnectionArgument", 0);
               }
         } break;

      case 6: {   /* conferenceCall operation Request */
            ConferenceCallArgument conferenceCallArg = new ConferenceCallArgument();
            conferenceCallArg.decode(decodeBuffer2);
               /* process the "conferenceCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ConferenceCallArgument was successful\n");
                  conferenceCallArg.print(System.out, "ConferenceCallArgument", 0);
               }
         } break;

      case 7: {   /* consultationCall operation Request */
            ConsultationCallArgument consultationCallArg = new ConsultationCallArgument();
            consultationCallArg.decode(decodeBuffer2);
               /* process the "consultationCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ConsultationCallArgument was successful\n");
                  consultationCallArg.print(System.out, "ConsultationCallArgument", 0);
               }
         } break;

      case 8: {   /* divertCall operation Request */
            DivertCallArgument divertCallArg = new DivertCallArgument();
            divertCallArg.decode(decodeBuffer2);
               /* process the "divertCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of DivertCallArgument was successful\n");
                  divertCallArg.print(System.out, "DivertCallArgument", 0);
               }
         } break;

      case 9: {   /* holdCall operation Request */
            HoldCallArgument holdCallArg = new HoldCallArgument();
            holdCallArg.decode(decodeBuffer2);
               /* process the "holdCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of HoldCallArgument was successful\n");
                  holdCallArg.print(System.out, "HoldCallArgument", 0);
               }
         } break;

      case 10: {   /* makeCall operation Request */
            MakeCallArgument makeCallArg = new MakeCallArgument();
            makeCallArg.decode(decodeBuffer2);
               /* process the "makeCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of MakeCallArgument was successful\n");
                  makeCallArg.print(System.out, "MakeCallArgument", 0);
               }
         } break;

      case 11: {   /* makePredictiveCall operation Request */
            MakePredictiveCallArgument makePredictiveCallArg = new MakePredictiveCallArgument();
            makePredictiveCallArg.decode(decodeBuffer2);
               /* process the "makePredictiveCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of MakePredictiveCallArgument was successful\n");
                  makePredictiveCallArg.print(System.out, "MakePredictiveCallArgument", 0);
               }
         } break;

      case 18: {   /* parkCall operation Request */
            ParkCallArgument parkCallArg = new ParkCallArgument();
            parkCallArg.decode(decodeBuffer2);
               /* process the "parkCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ParkCallArgument was successful\n");
                  parkCallArg.print(System.out, "ParkCallArgument", 0);
               }
         } break;

      case 12: {   /* queryDevice operation Request */
            QueryDeviceArgument queryDeviceArg = new QueryDeviceArgument();
            queryDeviceArg.decode(decodeBuffer2);
               /* process the "queryDevice" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of QueryDeviceArgument was successful\n");
                  queryDeviceArg.print(System.out, "QueryDeviceArgument", 0);
               }
         } break;

      case 13: {   /* reconnectCall operation Request */
            ReconnectCallArgument reconnectCallArg = new ReconnectCallArgument();
            reconnectCallArg.decode(decodeBuffer2);
               /* process the "reconnectCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ReconnectCallArgument was successful\n");
                  reconnectCallArg.print(System.out, "ReconnectCallArgument", 0);
               }
         } break;

      case 14: {   /* retrieveCall operation Request */
            RetrieveCallArgument retrieveCallArg = new RetrieveCallArgument();
            retrieveCallArg.decode(decodeBuffer2);
               /* process the "retrieveCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of RetrieveCallArgument was successful\n");
                  retrieveCallArg.print(System.out, "RetrieveCallArgument", 0);
               }
         } break;

      case 19: {   /* sendDTMFTones operation Request */
            SendDTMFTonesArgument sendDTMFTonesArg = new SendDTMFTonesArgument();
            sendDTMFTonesArg.decode(decodeBuffer2);
               /* process the "sendDTMFTones" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SendDTMFTonesArgument was successful\n");
                  sendDTMFTonesArg.print(System.out, "SendDTMFTonesArgument", 0);
               }
         } break;

      case 15: {   /* setFeature operation Request */
            SetFeatureArgument setFeatureArg = new SetFeatureArgument();
            setFeatureArg.decode(decodeBuffer2);
               /* process the "setFeature" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SetFeatureArgument was successful\n");
                  setFeatureArg.print(System.out, "SetFeatureArgument", 0);
               }
         } break;

      case 20: {   /* singleStepConf operation Request */
            SingleStepConfArgument singleStepConfArg = new SingleStepConfArgument();
            singleStepConfArg.decode(decodeBuffer2);
               /* process the "singleStepConf" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SingleStepConfArgument was successful\n");
                  singleStepConfArg.print(System.out, "SingleStepConfArgument", 0);
               }
         } break;

      case 50: {   /* singleStepTrans operation Request */
            SingleStepTransArgument singleStepTransArg = new SingleStepTransArgument();
            singleStepTransArg.decode(decodeBuffer2);
               /* process the "singleStepTrans" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SingleStepTransArgument was successful\n");
                  singleStepTransArg.print(System.out, "SingleStepTransArgument", 0);
               }
         } break;

      case 16: {   /* transferCall operation Request */
            TransferCallArgument transferCallArg = new TransferCallArgument();
            transferCallArg.decode(decodeBuffer2);
               /* process the "transferCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of TransferCallArgument was successful\n");
                  transferCallArg.print(System.out, "TransferCallArgument", 0);
               }
         } break;

      case 21: {   /* cSTAEventReport operation Request */
            CSTAEventReportArgument cSTAEventReportArg = new CSTAEventReportArgument();
            cSTAEventReportArg.decode(decodeBuffer2);
               if (trace) {
                  System.out.println ("Decode of CSTAEventReportArgument was successful\n");
                  cSTAEventReportArg.print(System.out, "CSTAEventReportArgument", 0);
               }
               /* process the "cSTAEventReport" operation Request in your application */
               processEvent(cSTAEventReportArg, trace);
         } break;

      case 31: {   /* routeRequest operation Request */
            RouteRequestArgument routeRequestArg = new RouteRequestArgument();
            routeRequestArg.decode(decodeBuffer2);
               /* process the "routeRequest" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of RouteRequestArgument was successful\n");
                  routeRequestArg.print(System.out, "RouteRequestArgument", 0);
               }
         } break;

      case 32: {   /* reRouteRequest operation Request */
            ReRouteRequestArgument reRouteRequestArg = new ReRouteRequestArgument();
            reRouteRequestArg.decode(decodeBuffer2);
               /* process the "reRouteRequest" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ReRouteRequestArgument was successful\n");
                  reRouteRequestArg.print(System.out, "ReRouteRequestArgument", 0);
               }
         } break;

      case 33: {   /* routeSelectRequest operation Request */
            RouteSelectRequestArgument routeSelectRequestArg = new RouteSelectRequestArgument();
            routeSelectRequestArg.decode(decodeBuffer2);
               /* process the "routeSelectRequest" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of RouteSelectRequestArgument was successful\n");
                  routeSelectRequestArg.print(System.out, "RouteSelectRequestArgument", 0);
               }
         } break;

      case 34: {   /* routeUsedRequest operation Request */
            RouteUsedRequestArgument routeUsedRequestArg = new RouteUsedRequestArgument();
            routeUsedRequestArg.decode(decodeBuffer2);
               /* process the "routeUsedRequest" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of RouteUsedRequestArgument was successful\n");
                  routeUsedRequestArg.print(System.out, "RouteUsedRequestArgument", 0);
               }
         } break;

      case 35: {   /* routeEndRequest operation Request */
            RouteEndRequestArgument routeEndRequestArg = new RouteEndRequestArgument();
            routeEndRequestArg.decode(decodeBuffer2);
               /* process the "routeEndRequest" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of RouteEndRequestArgument was successful\n");
                  routeEndRequestArg.print(System.out, "RouteEndRequestArgument", 0);
               }
         } break;

      case 51: {   /* escapeService operation Request */
            EscapeServiceArgument escapeServiceArg = new EscapeServiceArgument();
            escapeServiceArg.decode(decodeBuffer2);
               /* process the "escapeService" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of EscapeServiceArgument was successful\n");
                  escapeServiceArg.print(System.out, "EscapeServiceArgument", 0);
               }
         } break;

      case 52: {   /* systemStatus operation Request */
            SystemStatusArgument systemStatusArg = new SystemStatusArgument();
            systemStatusArg.decode(decodeBuffer2);
               /* process the "systemStatus" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SystemStatusArgument was successful\n");
                  systemStatusArg.print(System.out, "SystemStatusArgument", 0);
               }
         } break;

      case 71: {   /* monitorStart operation Request */
            MonitorStartArgument monitorStartArg = new MonitorStartArgument();
            monitorStartArg.decode(decodeBuffer2);
               /* process the "monitorStart" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of MonitorStartArgument was successful\n");
                  monitorStartArg.print(System.out, "MonitorStartArgument", 0);
               }
         } break;

      case 72: {   /* changeMonitorFilter operation Request */
            ChangeMonitorFilterArgument changeMonitorFilterArg = new ChangeMonitorFilterArgument();
            changeMonitorFilterArg.decode(decodeBuffer2);
               /* process the "changeMonitorFilter" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ChangeMonitorFilterArgument was successful\n");
                  changeMonitorFilterArg.print(System.out, "ChangeMonitorFilterArgument", 0);
               }
         } break;

      case 73: {   /* monitorStop operation Request */
            MonitorStopArgument monitorStopArg = new MonitorStopArgument();
            monitorStopArg.decode(decodeBuffer2);
               /* process the "monitorStop" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of MonitorStopArgument was successful\n");
                  monitorStopArg.print(System.out, "MonitorStopArgument", 0);
               }
         } break;

      case 74: {   /* snapshotDevice operation Request */
            SnapshotDeviceArgument snapshotDeviceArg = new SnapshotDeviceArgument();
            snapshotDeviceArg.decode(decodeBuffer2);
               /* process the "snapshotDevice" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SnapshotDeviceArgument was successful\n");
                  snapshotDeviceArg.print(System.out, "SnapshotDeviceArgument", 0);
               }
         } break;

      case 75: {   /* snapshotCall operation Request */
            SnapshotCallArgument snapshotCallArg = new SnapshotCallArgument();
            snapshotCallArg.decode(decodeBuffer2);
               /* process the "snapshotCall" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SnapshotCallArgument was successful\n");
                  snapshotCallArg.print(System.out, "SnapshotCallArgument", 0);
               }
         } break;

      case 110: {   /* startDataPath operation Request */
            StartDataPathArgument startDataPathArg = new StartDataPathArgument();
            startDataPathArg.decode(decodeBuffer2);
               /* process the "startDataPath" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of StartDataPathArgument was successful\n");
                  startDataPathArg.print(System.out, "StartDataPathArgument", 0);
               }
         } break;

      case 111: {   /* stopDataPath operation Request */
            StopDataPathArgument stopDataPathArg = new StopDataPathArgument();
            stopDataPathArg.decode(decodeBuffer2);
               /* process the "stopDataPath" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of StopDataPathArgument was successful\n");
                  stopDataPathArg.print(System.out, "StopDataPathArgument", 0);
               }
         } break;

      case 112: {   /* sendData operation Request */
            SendDataArgument sendDataArg = new SendDataArgument();
            sendDataArg.decode(decodeBuffer2);
               /* process the "sendData" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SendDataArgument was successful\n");
                  sendDataArg.print(System.out, "SendDataArgument", 0);
               }
         } break;

      case 113: {   /* sendMulticastData operation Request */
            SendMulticastDataArgument sendMulticastDataArg = new SendMulticastDataArgument();
            sendMulticastDataArg.decode(decodeBuffer2);
               /* process the "sendMulticastData" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SendMulticastDataArgument was successful\n");
                  sendMulticastDataArg.print(System.out, "SendMulticastDataArgument", 0);
               }
         } break;

      case 114: {   /* sendBroadcastData operation Request */
            SendBroadcastDataArgument sendBroadcastDataArg = new SendBroadcastDataArgument();
            sendBroadcastDataArg.decode(decodeBuffer2);
               /* process the "sendBroadcastData" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SendBroadcastDataArgument was successful\n");
                  sendBroadcastDataArg.print(System.out, "SendBroadcastDataArgument", 0);
               }
         } break;

      case 115: {   /* suspendDataPath operation Request */
            SuspendDataPathArgument suspendDataPathArg = new SuspendDataPathArgument();
            suspendDataPathArg.decode(decodeBuffer2);
               /* process the "suspendDataPath" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SuspendDataPathArgument was successful\n");
                  suspendDataPathArg.print(System.out, "SuspendDataPathArgument", 0);
               }
         } break;

      case 116: {   /* dataPathSuspended operation Request */
            DataPathSuspendedArgument dataPathSuspendedArg = new DataPathSuspendedArgument();
            dataPathSuspendedArg.decode(decodeBuffer2);
               /* process the "dataPathSuspended" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of DataPathSuspendedArgument was successful\n");
                  dataPathSuspendedArg.print(System.out, "DataPathSuspendedArgument", 0);
               }
         } break;

      case 117: {   /* resumeDataPath operation Request */
            ResumeDataPathArgument resumeDataPathArg = new ResumeDataPathArgument();
            resumeDataPathArg.decode(decodeBuffer2);
               /* process the "resumeDataPath" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ResumeDataPathArgument was successful\n");
                  resumeDataPathArg.print(System.out, "ResumeDataPathArgument", 0);
               }
         } break;

      case 118: {   /* dataPathResumed operation Request */
            DataPathResumedArgument dataPathResumedArg = new DataPathResumedArgument();
            dataPathResumedArg.decode(decodeBuffer2);
               /* process the "dataPathResumed" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of DataPathResumedArgument was successful\n");
                  dataPathResumedArg.print(System.out, "DataPathResumedArgument", 0);
               }
         } break;

      case 119: {   /* fastData operation Request */
            FastDataArgument fastDataArg = new FastDataArgument();
            fastDataArg.decode(decodeBuffer2);
               /* process the "fastData" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of FastDataArgument was successful\n");
                  fastDataArg.print(System.out, "FastDataArgument", 0);
               }
         } break;

      case 500: {   /* concatenateMessage operation Request */
            ConcatenateMessageArgument concatenateMessageArg = new ConcatenateMessageArgument();
            concatenateMessageArg.decode(decodeBuffer2);
               /* process the "concatenateMessage" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ConcatenateMessageArgument was successful\n");
                  concatenateMessageArg.print(System.out, "ConcatenateMessageArgument", 0);
               }
         } break;

      case 501: {   /* deleteMessage operation Request */
            DeleteMessageArgument deleteMessageArg = new DeleteMessageArgument();
            deleteMessageArg.decode(decodeBuffer2);
               /* process the "deleteMessage" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of DeleteMessageArgument was successful\n");
                  deleteMessageArg.print(System.out, "DeleteMessageArgument", 0);
               }
         } break;

      case 502: {   /* playMessage operation Request */
            PlayMessageArgument playMessageArg = new PlayMessageArgument();
            playMessageArg.decode(decodeBuffer2);
               /* process the "playMessage" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of PlayMessageArgument was successful\n");
                  playMessageArg.print(System.out, "PlayMessageArgument", 0);
               }
         } break;

      case 503: {   /* queryVoiceAttribute operation Request */
            QueryVoiceAttributeArgument queryVoiceAttributeArg = new QueryVoiceAttributeArgument();
            queryVoiceAttributeArg.decode(decodeBuffer2);
               /* process the "queryVoiceAttribute" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of QueryVoiceAttributeArgument was successful\n");
                  queryVoiceAttributeArg.print(System.out, "QueryVoiceAttributeArgument", 0);
               }
         } break;

      case 511: {   /* recordMessage operation Request */
            RecordMessageArgument recordMessageArg = new RecordMessageArgument();
            recordMessageArg.decode(decodeBuffer2);
               /* process the "recordMessage" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of RecordMessageArgument was successful\n");
                  recordMessageArg.print(System.out, "RecordMessageArgument", 0);
               }
         } break;

      case 504: {   /* reposition operation Request */
            RepositionArgument repositionArg = new RepositionArgument();
            repositionArg.decode(decodeBuffer2);
               /* process the "reposition" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of RepositionArgument was successful\n");
                  repositionArg.print(System.out, "RepositionArgument", 0);
               }
         } break;

      case 505: {   /* resume operation Request */
            ResumeArgument resumeArg = new ResumeArgument();
            resumeArg.decode(decodeBuffer2);
               /* process the "resume" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ResumeArgument was successful\n");
                  resumeArg.print(System.out, "ResumeArgument", 0);
               }
         } break;

      case 506: {   /* review operation Request */
            ReviewArgument reviewArg = new ReviewArgument();
            reviewArg.decode(decodeBuffer2);
               /* process the "review" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of ReviewArgument was successful\n");
                  reviewArg.print(System.out, "ReviewArgument", 0);
               }
         } break;

      case 507: {   /* setVoiceAttribute operation Request */
            SetVoiceAttributeArgument setVoiceAttributeArg = new SetVoiceAttributeArgument();
            setVoiceAttributeArg.decode(decodeBuffer2);
               /* process the "setVoiceAttribute" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SetVoiceAttributeArgument was successful\n");
                  setVoiceAttributeArg.print(System.out, "SetVoiceAttributeArgument", 0);
               }
         } break;

      case 508: {   /* stop operation Request */
            StopArgument stopArg = new StopArgument();
            stopArg.decode(decodeBuffer2);
               /* process the "stop" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of StopArgument was successful\n");
                  stopArg.print(System.out, "StopArgument", 0);
               }
         } break;

      case 509: {   /* suspend operation Request */
            SuspendArgument suspendArg = new SuspendArgument();
            suspendArg.decode(decodeBuffer2);
               /* process the "suspend" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SuspendArgument was successful\n");
                  suspendArg.print(System.out, "SuspendArgument", 0);
               }
         } break;

      case 510: {   /* synthesizeMessage operation Request */
            SynthesizeMessageArgument synthesizeMessageArg = new SynthesizeMessageArgument();
            synthesizeMessageArg.decode(decodeBuffer2);
               /* process the "synthesizeMessage" operation Request in your application */
               if (trace) {
                  System.out.println ("Decode of SynthesizeMessageArgument was successful\n");
                  synthesizeMessageArg.print(System.out, "SynthesizeMessageArgument", 0);
               }
         } break;
      default: {
         System.out.println ("error: invalid operation code, not defined in csta phase 3\n");
         } break;
   }
}

static void processEvent(CSTAEventReportArgument eventReportArg, boolean trace)
{
   //Process the event from EventReportArgument type

}

static void processReturnResult(CSTA_ROSE_PDU pdu, boolean trace)
   throws IOException, Asn1Exception
{
   /*
   ReturnResult.result.result(opentype) needs to be decoded
   using ReturnResult.result.opcode value as defined in Table 1.
   */
   ReturnResult returnResult = (ReturnResult)pdu.getElement();
   if ( returnResult.result.opcode.getChoiceID() != Code._LOCAL ) {      
      System.out.println ("ROSE Operation's ReturnResult.result.result type is not known\n");
      return;
   }

   Asn1BerDecodeBuffer decodeBuffer2 = new Asn1BerDecodeBuffer(
         returnResult.result.result.value );

   Asn1Integer local = (Asn1Integer) returnResult.result.opcode.getElement();
   switch( (int) local.value ) {
      case 1 : {  /* alternateCall operation Response*/
            AlternateCallResult alternateCallRes = new AlternateCallResult();
            alternateCallRes.decode(decodeBuffer2);
               /* process the "alternateCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of AlternateCallResult was successful\n");
                  alternateCallRes.print(System.out, "AlternateCallResult", 0);
               }
         } break;

      case 2 : {  /* answerCall operation Response*/
            AnswerCallResult answerCallRes = new AnswerCallResult();
            answerCallRes.decode(decodeBuffer2);
               /* process the "answerCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of AnswerCallResult was successful\n");
                  answerCallRes.print(System.out, "AnswerCallResult", 0);
               }
         } break;

      case 17 : {  /* associateData operation Response*/
            AssociateDataResult associateDataRes = new AssociateDataResult();
            associateDataRes.decode(decodeBuffer2);
               /* process the "associateData" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of AssociateDataResult was successful\n");
                  associateDataRes.print(System.out, "AssociateDataResult", 0);
               }
         } break;

      case 3 : {  /* callCompletion operation Response*/
            CallCompletionResult callCompletionRes = new CallCompletionResult();
            callCompletionRes.decode(decodeBuffer2);
               /* process the "callCompletion" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of CallCompletionResult was successful\n");
                  callCompletionRes.print(System.out, "CallCompletionResult", 0);
               }
         } break;

      case 4 : {  /* clearCall operation Response*/
            ClearCallResult clearCallRes = new ClearCallResult();
            clearCallRes.decode(decodeBuffer2);
               /* process the "clearCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of ClearCallResult was successful\n");
                  clearCallRes.print(System.out, "ClearCallResult", 0);
               }
         } break;

      case 5 : {  /* clearConnection operation Response*/
            ClearConnectionResult clearConnectionRes = new ClearConnectionResult();
            clearConnectionRes.decode(decodeBuffer2);
               /* process the "clearConnection" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of ClearConnectionResult was successful\n");
                  clearConnectionRes.print(System.out, "ClearConnectionResult", 0);
               }
         } break;

      case 6 : {  /* conferenceCall operation Response*/
            ConferenceCallResult conferenceCallRes = new ConferenceCallResult();
            conferenceCallRes.decode(decodeBuffer2);
               /* process the "conferenceCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of ConferenceCallResult was successful\n");
                  conferenceCallRes.print(System.out, "ConferenceCallResult", 0);
               }
         } break;

      case 7 : {  /* consultationCall operation Response*/
            ConsultationCallResult consultationCallRes = new ConsultationCallResult();
            consultationCallRes.decode(decodeBuffer2);
               /* process the "consultationCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of ConsultationCallResult was successful\n");
                  consultationCallRes.print(System.out, "ConsultationCallResult", 0);
               }
         } break;

      case 8 : {  /* divertCall operation Response*/
            DivertCallResult divertCallRes = new DivertCallResult();
            divertCallRes.decode(decodeBuffer2);
               /* process the "divertCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of DivertCallResult was successful\n");
                  divertCallRes.print(System.out, "DivertCallResult", 0);
               }
         } break;

      case 9 : {  /* holdCall operation Response*/
            HoldCallResult holdCallRes = new HoldCallResult();
            holdCallRes.decode(decodeBuffer2);
               /* process the "holdCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of HoldCallResult was successful\n");
                  holdCallRes.print(System.out, "HoldCallResult", 0);
               }
         } break;

      case 10 : {  /* makeCall operation Response*/
            MakeCallResult makeCallRes = new MakeCallResult();
            makeCallRes.decode(decodeBuffer2);
               /* process the "makeCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of MakeCallResult was successful\n");
                  makeCallRes.print(System.out, "MakeCallResult", 0);
               }
         } break;

      case 11 : {  /* makePredictiveCall operation Response*/
            MakePredictiveCallResult makePredictiveCallRes = new MakePredictiveCallResult();
            makePredictiveCallRes.decode(decodeBuffer2);
               /* process the "makePredictiveCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of MakePredictiveCallResult was successful\n");
                  makePredictiveCallRes.print(System.out, "MakePredictiveCallResult", 0);
               }
         } break;

      case 18 : {  /* parkCall operation Response*/
            ParkCallResult parkCallRes = new ParkCallResult();
            parkCallRes.decode(decodeBuffer2);
               /* process the "parkCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of ParkCallResult was successful\n");
                  parkCallRes.print(System.out, "ParkCallResult", 0);
               }
         } break;

      case 12 : {  /* queryDevice operation Response*/
            QueryDeviceResult queryDeviceRes = new QueryDeviceResult();
            queryDeviceRes.decode(decodeBuffer2);
               /* process the "queryDevice" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of QueryDeviceResult was successful\n");
                  queryDeviceRes.print(System.out, "QueryDeviceResult", 0);
               }
         } break;

      case 13 : {  /* reconnectCall operation Response*/
            ReconnectCallResult reconnectCallRes = new ReconnectCallResult();
            reconnectCallRes.decode(decodeBuffer2);
               /* process the "reconnectCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of ReconnectCallResult was successful\n");
                  reconnectCallRes.print(System.out, "ReconnectCallResult", 0);
               }
         } break;

      case 14 : {  /* retrieveCall operation Response*/
            RetrieveCallResult retrieveCallRes = new RetrieveCallResult();
            retrieveCallRes.decode(decodeBuffer2);
               /* process the "retrieveCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of RetrieveCallResult was successful\n");
                  retrieveCallRes.print(System.out, "RetrieveCallResult", 0);
               }
         } break;

      case 19 : {  /* sendDTMFTones operation Response*/
            SendDTMFTonesResult sendDTMFTonesRes = new SendDTMFTonesResult();
            sendDTMFTonesRes.decode(decodeBuffer2);
               /* process the "sendDTMFTones" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SendDTMFTonesResult was successful\n");
                  sendDTMFTonesRes.print(System.out, "SendDTMFTonesResult", 0);
               }
         } break;

      case 15 : {  /* setFeature operation Response*/
            SetFeatureResult setFeatureRes = new SetFeatureResult();
            setFeatureRes.decode(decodeBuffer2);
               /* process the "setFeature" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SetFeatureResult was successful\n");
                  setFeatureRes.print(System.out, "SetFeatureResult", 0);
               }
         } break;

      case 20 : {  /* singleStepConf operation Response*/
            SingleStepConfResult singleStepConfRes = new SingleStepConfResult();
            singleStepConfRes.decode(decodeBuffer2);
               /* process the "singleStepConf" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SingleStepConfResult was successful\n");
                  singleStepConfRes.print(System.out, "SingleStepConfResult", 0);
               }
         } break;

      case 50 : {  /* singleStepTrans operation Response*/
            SingleStepTransResult singleStepTransRes = new SingleStepTransResult();
            singleStepTransRes.decode(decodeBuffer2);
               /* process the "singleStepTrans" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SingleStepTransResult was successful\n");
                  singleStepTransRes.print(System.out, "SingleStepTransResult", 0);
               }
         } break;

      case 16 : {  /* transferCall operation Response*/
            TransferCallResult transferCallRes = new TransferCallResult();
            transferCallRes.decode(decodeBuffer2);
               /* process the "transferCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of TransferCallResult was successful\n");
                  transferCallRes.print(System.out, "TransferCallResult", 0);
               }
         } break;

      case 51 : {  /* escapeService operation Response*/
            EscapeServiceResult escapeServiceRes = new EscapeServiceResult();
            escapeServiceRes.decode(decodeBuffer2);
               /* process the "escapeService" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of EscapeServiceResult was successful\n");
                  escapeServiceRes.print(System.out, "EscapeServiceResult", 0);
               }
         } break;

      case 52 : {  /* systemStatus operation Response*/
            SystemStatusResult systemStatusRes = new SystemStatusResult();
            systemStatusRes.decode(decodeBuffer2);
               /* process the "systemStatus" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SystemStatusResult was successful\n");
                  systemStatusRes.print(System.out, "SystemStatusResult", 0);
               }
         } break;

      case 71 : {  /* monitorStart operation Response*/
            MonitorStartResult monitorStartRes = new MonitorStartResult();
            monitorStartRes.decode(decodeBuffer2);
               /* process the "monitorStart" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of MonitorStartResult was successful\n");
                  monitorStartRes.print(System.out, "MonitorStartResult", 0);
               }
         } break;

      case 72 : {  /* changeMonitorFilter operation Response*/
            ChangeMonitorFilterResult changeMonitorFilterRes = new ChangeMonitorFilterResult();
            changeMonitorFilterRes.decode(decodeBuffer2);
               /* process the "changeMonitorFilter" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of ChangeMonitorFilterResult was successful\n");
                  changeMonitorFilterRes.print(System.out, "ChangeMonitorFilterResult", 0);
               }
         } break;

      case 73 : {  /* monitorStop operation Response*/
            MonitorStopResult monitorStopRes = new MonitorStopResult();
            monitorStopRes.decode(decodeBuffer2);
               /* process the "monitorStop" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of MonitorStopResult was successful\n");
                  monitorStopRes.print(System.out, "MonitorStopResult", 0);
               }
         } break;

      case 74 : {  /* snapshotDevice operation Response*/
            SnapshotDeviceResult snapshotDeviceRes = new SnapshotDeviceResult();
            snapshotDeviceRes.decode(decodeBuffer2);
               /* process the "snapshotDevice" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SnapshotDeviceResult was successful\n");
                  snapshotDeviceRes.print(System.out, "SnapshotDeviceResult", 0);
               }
         } break;

      case 75 : {  /* snapshotCall operation Response*/
            SnapshotCallResult snapshotCallRes = new SnapshotCallResult();
            snapshotCallRes.decode(decodeBuffer2);
               /* process the "snapshotCall" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SnapshotCallResult was successful\n");
                  snapshotCallRes.print(System.out, "SnapshotCallResult", 0);
               }
         } break;

      case 110 : {  /* startDataPath operation Response*/
            StartDataPathResult startDataPathRes = new StartDataPathResult();
            startDataPathRes.decode(decodeBuffer2);
               /* process the "startDataPath" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of StartDataPathResult was successful\n");
                  startDataPathRes.print(System.out, "StartDataPathResult", 0);
               }
         } break;

      case 111 : {  /* stopDataPath operation Response*/
            StopDataPathResult stopDataPathRes = new StopDataPathResult();
            stopDataPathRes.decode(decodeBuffer2);
               /* process the "stopDataPath" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of StopDataPathResult was successful\n");
                  stopDataPathRes.print(System.out, "StopDataPathResult", 0);
               }
         } break;

      case 112 : {  /* sendData operation Response*/
            SendDataResult sendDataRes = new SendDataResult();
            sendDataRes.decode(decodeBuffer2);
               /* process the "sendData" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SendDataResult was successful\n");
                  sendDataRes.print(System.out, "SendDataResult", 0);
               }
         } break;

      case 113 : {  /* sendMulticastData operation Response*/
            SendMulticastDataResult sendMulticastDataRes = new SendMulticastDataResult();
            sendMulticastDataRes.decode(decodeBuffer2);
               /* process the "sendMulticastData" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SendMulticastDataResult was successful\n");
                  sendMulticastDataRes.print(System.out, "SendMulticastDataResult", 0);
               }
         } break;

      case 114 : {  /* sendBroadcastData operation Response*/
            SendBroadcastDataResult sendBroadcastDataRes = new SendBroadcastDataResult();
            sendBroadcastDataRes.decode(decodeBuffer2);
               /* process the "sendBroadcastData" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SendBroadcastDataResult was successful\n");
                  sendBroadcastDataRes.print(System.out, "SendBroadcastDataResult", 0);
               }
         } break;

      case 115 : {  /* suspendDataPath operation Response*/
            SuspendDataPathResult suspendDataPathRes = new SuspendDataPathResult();
            suspendDataPathRes.decode(decodeBuffer2);
               /* process the "suspendDataPath" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SuspendDataPathResult was successful\n");
                  suspendDataPathRes.print(System.out, "SuspendDataPathResult", 0);
               }
         } break;

      case 116 : {  /* dataPathSuspended operation Response*/
            DataPathSuspendedResult dataPathSuspendedRes = new DataPathSuspendedResult();
            dataPathSuspendedRes.decode(decodeBuffer2);
               /* process the "dataPathSuspended" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of DataPathSuspendedResult was successful\n");
                  dataPathSuspendedRes.print(System.out, "DataPathSuspendedResult", 0);
               }
         } break;

      case 117 : {  /* resumeDataPath operation Response*/
            ResumeDataPathResult resumeDataPathRes = new ResumeDataPathResult();
            resumeDataPathRes.decode(decodeBuffer2);
               /* process the "resumeDataPath" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of ResumeDataPathResult was successful\n");
                  resumeDataPathRes.print(System.out, "ResumeDataPathResult", 0);
               }
         } break;

      case 118 : {  /* dataPathResumed operation Response*/
            DataPathResumedResult dataPathResumedRes = new DataPathResumedResult();
            dataPathResumedRes.decode(decodeBuffer2);
               /* process the "dataPathResumed" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of DataPathResumedResult was successful\n");
                  dataPathResumedRes.print(System.out, "DataPathResumedResult", 0);
               }
         } break;

      case 119 : {  /* fastData operation Response*/
            FastDataResult fastDataRes = new FastDataResult();
            fastDataRes.decode(decodeBuffer2);
               /* process the "fastData" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of FastDataResult was successful\n");
                  fastDataRes.print(System.out, "FastDataResult", 0);
               }
         } break;

      case 500 : {  /* concatenateMessage operation Response*/
            ConcatenateMessageResult concatenateMessageRes = new ConcatenateMessageResult();
            concatenateMessageRes.decode(decodeBuffer2);
               /* process the "concatenateMessage" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of ConcatenateMessageResult was successful\n");
                  concatenateMessageRes.print(System.out, "ConcatenateMessageResult", 0);
               }
         } break;

      case 501 : {  /* deleteMessage operation Response*/
            DeleteMessageResult deleteMessageRes = new DeleteMessageResult();
            deleteMessageRes.decode(decodeBuffer2);
               /* process the "deleteMessage" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of DeleteMessageResult was successful\n");
                  deleteMessageRes.print(System.out, "DeleteMessageResult", 0);
               }
         } break;

      case 502 : {  /* playMessage operation Response*/
            PlayMessageResult playMessageRes = new PlayMessageResult();
            playMessageRes.decode(decodeBuffer2);
               /* process the "playMessage" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of PlayMessageResult was successful\n");
                  playMessageRes.print(System.out, "PlayMessageResult", 0);
               }
         } break;

      case 503 : {  /* queryVoiceAttribute operation Response*/
            QueryVoiceAttributeResult queryVoiceAttributeRes = new QueryVoiceAttributeResult();
            queryVoiceAttributeRes.decode(decodeBuffer2);
               /* process the "queryVoiceAttribute" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of QueryVoiceAttributeResult was successful\n");
                  queryVoiceAttributeRes.print(System.out, "QueryVoiceAttributeResult", 0);
               }
         } break;

      case 511 : {  /* recordMessage operation Response*/
            RecordMessageResult recordMessageRes = new RecordMessageResult();
            recordMessageRes.decode(decodeBuffer2);
               /* process the "recordMessage" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of RecordMessageResult was successful\n");
                  recordMessageRes.print(System.out, "RecordMessageResult", 0);
               }
         } break;

      case 504 : {  /* reposition operation Response*/
            RepositionResult repositionRes = new RepositionResult();
            repositionRes.decode(decodeBuffer2);
               /* process the "reposition" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of RepositionResult was successful\n");
                  repositionRes.print(System.out, "RepositionResult", 0);
               }
         } break;

      case 505 : {  /* resume operation Response*/
            ResumeResult resumeRes = new ResumeResult();
            resumeRes.decode(decodeBuffer2);
               /* process the "resume" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of ResumeResult was successful\n");
                  resumeRes.print(System.out, "ResumeResult", 0);
               }
         } break;

      case 506 : {  /* review operation Response*/
            ReviewResult reviewRes = new ReviewResult();
            reviewRes.decode(decodeBuffer2);
               /* process the "review" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of ReviewResult was successful\n");
                  reviewRes.print(System.out, "ReviewResult", 0);
               }
         } break;

      case 507 : {  /* setVoiceAttribute operation Response*/
            SetVoiceAttributeResult setVoiceAttributeRes = new SetVoiceAttributeResult();
            setVoiceAttributeRes.decode(decodeBuffer2);
               /* process the "setVoiceAttribute" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SetVoiceAttributeResult was successful\n");
                  setVoiceAttributeRes.print(System.out, "SetVoiceAttributeResult", 0);
               }
         } break;

      case 508 : {  /* stop operation Response*/
            StopResult stopRes = new StopResult();
            stopRes.decode(decodeBuffer2);
               /* process the "stop" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of StopResult was successful\n");
                  stopRes.print(System.out, "StopResult", 0);
               }
         } break;

      case 509 : {  /* suspend operation Response*/
            SuspendResult suspendRes = new SuspendResult();
            suspendRes.decode(decodeBuffer2);
               /* process the "suspend" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SuspendResult was successful\n");
                  suspendRes.print(System.out, "SuspendResult", 0);
               }
         } break;

      case 510 : {  /* synthesizeMessage operation Response*/
            SynthesizeMessageResult synthesizeMessageRes = new SynthesizeMessageResult();
            synthesizeMessageRes.decode(decodeBuffer2);
               /* process the "synthesizeMessage" operation response in your application */
               if (trace) {
                  System.out.println ("Decode of SynthesizeMessageResult was successful\n");
                  synthesizeMessageRes.print(System.out, "SynthesizeMessageResult", 0);
               }
         } break;

      default: { /* error: invalid operation code, not defined in csta phase 3*/
         System.out.println ("error: invalid operation code, not defined in csta phase 3\n");
         } break;
   }
}


static void processReturnError(CSTA_ROSE_PDU pdu, boolean trace)
   throws Asn1Exception, IOException
{
   /* 
   return error processing will require to decode the ReturnError.parameter
   opentype in to real error type, only one possible error type can be returned
   in csta 2, which is "UniversalFailure" 
   
   ReturnError.errcode field is used to find out the real type for 
   ReturnError.parameter(opentype). Real type for all the operation
   in Table 1(i.e csta3) is "UniversalFailure"
   */
      ReturnError returnError = (ReturnError) pdu.getElement();
      
      Asn1BerDecodeBuffer decodeBuffer2 = new Asn1BerDecodeBuffer(
            returnError.parameter.value );

      UniversalFailure uniFailure = new UniversalFailure();
      uniFailure.decode(decodeBuffer2);

         if (trace) {
            System.out.println ("Decode of ReturnError was successful\n");
            uniFailure.print(System.out, "UniversalFailure", 0);
         }         
}





static void processReject(CSTA_ROSE_PDU pdu, boolean trace)
{
   /* process the reject in your application */
}

}