package sample.MakeCallResponse;

import java.io.FileOutputStream;
import java.io.PrintStream;

import com.objsys.asn1j.runtime.*;
import com.objsys.csta2.*;

/* This test driver program encodes a data record and writes the        */
/* encoded result to an output file..                                   */

public class Writer {

   public static final void main (String[] args)
   {
      try {

         /* Process command line arguments */
         String filename = new String ("message.dat");
         boolean trace = true;
      
         // Process command line arguments
      
         if (args.length > 0) {
           for (int i = 0; i < args.length; i++) {
              if (args[i].equals ("-v")) 
                  Diag.instance().setEnabled (true);
              else if (args[i].equals ("-o")) 
                  filename = new String (args[++i]);
              else if (args[i].equals ("-notrace")) trace = false;
              else {
                  System.out.println ("usage: Writer [ -v ] [ -o <filename>");
                  System.out.println ("   -v  verbose mode: print trace info");
                  System.out.println ("   -o <filename>  " +
                                      "write encoded msg to <filename>");
                  System.out.println ("   -notrace  do not display trace info");
                  return;
              }
           }
         }

         /* Create encode buffer */
         Asn1BerEncodeBuffer encodeBuffer = new Asn1BerEncodeBuffer();
   
         /* Encode operation argument */
         encodeMakeCallResponse (encodeBuffer);
   
         /* Encode ROSE header on top of encoded argument */
         encodeROSEResponseHeader (encodeBuffer);
         
         if (trace) {
            System.out.println ("Encoding was successful");
            System.out.println ("Hex dump of encoded record:");
            encodeBuffer.hexDump ();
            System.out.println ("Binary dump:");
            encodeBuffer.binDump ();
        }
         
   
         // Write the encoded record to a file
         encodeBuffer.write (new FileOutputStream (filename));
   
         // Generate a dump file for comparisons
         encodeBuffer.hexDump 
             (new PrintStream (new FileOutputStream ("message.dmp")));
   
      }
      catch (Exception e) {
         System.out.println (e.getMessage());
         e.printStackTrace();           
         return;
     }
  }

   /* Encode "makeCall" operation response */
   
   private static void encodeMakeCallResponse (Asn1BerEncodeBuffer encodeBuffer)
      throws Asn1Exception
   {
      MakeCallResult makeCallResult = new MakeCallResult();
   
      /* Set ConnectionID option */  
      ConnectionID connectionId = new ConnectionID();
      byte data[] = new byte[] { 0x10 };
      connectionId.call = new Asn1OctetString(data);
      DeviceID staticID = new DeviceID();
      staticID.set_dialingNumber (new NumberDigits("22343"));
      connectionId.device = new ConnectionID_device();
      connectionId.device.set_staticID(staticID);
      makeCallResult.set_initiatedCall(connectionId);
   
      /* Encode */ 
      makeCallResult.encode(encodeBuffer);
   }
   
   /* Encode ROSE header */   
   private static void encodeROSEResponseHeader (
         Asn1BerEncodeBuffer encodeBuffer )
      throws Asn1Exception
   {
      CSTA_ROSE_PDU pdu = new CSTA_ROSE_PDU();
      ReturnResult returnResult = new ReturnResult();
   
      /* Populate header structure */
      returnResult.invokeId = new InvokeId();
      returnResult.invokeId.set_present(new Asn1Integer(1)); /* arbitrary number: should be unique */
      returnResult.result = new ReturnResult_result();
      returnResult.result.opcode = new Code();
      returnResult.result.opcode.set_local(new Asn1Integer(10)); /* operation code for "makeCall" operation from Table 1 */
         
      /* This is where we get the previously encoded message component..   */
      returnResult.result.result = new Asn1OpenType(encodeBuffer);
   
      pdu.set_returnResult(returnResult);
   
      /* Encode */
      pdu.encode(encodeBuffer);
   }
}